@@ -24,7 +24,7 @@ gdnsd utility.
 
 Supported Knot versions: >= 2.1, < 3
 
-`User documentation <backends/gdnsd_agent.html>`_
+`User documentation <../../admin/backends/gdnsd_agent.html>`_
 
 .. WARNING::
 
@@ -40,8 +40,9 @@ Configured in [service:agent:gdnsd]
 
 import errno
 import os
-import tempfile
 import string
+import tempfile
+import warnings
 
 import dns
 import dns.resolver
@@ -49,12 +50,12 @@ from oslo_concurrency.processutils import ProcessExecutionError
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate import utils
-from designate import exceptions
 from designate.backend.agent_backend import base
+from designate import exceptions
+from designate import utils
 
+CFG_GROUP_NAME = 'backend:agent:gdnsd'
 LOG = logging.getLogger(__name__)
-CFG_GROUP = 'backend:agent:gdnsd'
 # rootwrap requires a command name instead of full path
 GDNSD_DEFAULT_PATH = 'gdnsd'
 CONFDIR_PATH = '/etc/gdnsd'
@@ -62,25 +63,6 @@ SOA_QUERY_TIMEOUT = 1
 ZONE_FILE_PERMISSIONS = 0o0644
 
 
-"""GROUP = backend:agent:gdnsd"""
-gdnsd_group = cfg.OptGroup(
-            name='backend:agent:gdnsd', title="Configuration for gdnsd backend"
-        )
-gdnsd_opts = [
-    cfg.StrOpt('gdnsd-cmd-name',
-               help='gdnsd executable path or rootwrap command name',
-               default='gdnsd'),
-    cfg.StrOpt('confdir-path',
-               help='gdnsd configuration directory path',
-               default='/etc/gdnsd'),
-    cfg.StrOpt('query-destination', default='127.0.0.1',
-               help='Host to query when finding zones')
-]
-
-cfg.CONF.register_group(gdnsd_group)
-cfg.CONF.register_opts(gdnsd_opts, group=gdnsd_group)
-
-
 def filter_exceptions(fn):
     # Let Backend() exceptions pass through, log out every other exception
     # and re-raise it as Backend()
@@ -100,23 +82,27 @@ class GdnsdBackend(base.AgentBackend):
     __plugin_name__ = 'gdnsd'
     __backend_status__ = 'experimental'
 
-    @classmethod
-    def get_cfg_opts(cls):
-        return [(gdnsd_group, gdnsd_opts)]
-
     def __init__(self, *a, **kw):
         """Configure the backend"""
         super(GdnsdBackend, self).__init__(*a, **kw)
 
-        self._gdnsd_cmd_name = cfg.CONF[CFG_GROUP].gdnsd_cmd_name
+        warning_msg = ('The designate agent framework and backend driver "{}" '
+                       'are deprecated as of the Antelope (2023.1) release '
+                       'and will be removed in the "C" '
+                       'release.'.format(self.__plugin_name__))
+        warnings.warn(warning_msg, DeprecationWarning)
+
+        self._gdnsd_cmd_name = cfg.CONF[CFG_GROUP_NAME].gdnsd_cmd_name
         LOG.info("gdnsd command: %r", self._gdnsd_cmd_name)
-        self._confdir_path = cfg.CONF[CFG_GROUP].confdir_path
+        self._confdir_path = cfg.CONF[CFG_GROUP_NAME].confdir_path
         self._zonedir_path = os.path.join(self._confdir_path, 'zones')
         LOG.info("gdnsd conf directory: %r", self._confdir_path)
         self._resolver = dns.resolver.Resolver(configure=False)
         self._resolver.timeout = SOA_QUERY_TIMEOUT
         self._resolver.lifetime = SOA_QUERY_TIMEOUT
-        self._resolver.nameservers = [cfg.CONF[CFG_GROUP].query_destination]
+        self._resolver.nameservers = [
+            cfg.CONF[CFG_GROUP_NAME].query_destination
+        ]
         LOG.info("Resolvers: %r", self._resolver.nameservers)
         self._check_dirs(self._zonedir_path)
 
@@ -133,7 +119,7 @@ class GdnsdBackend(base.AgentBackend):
         """
         try:
             out, err = utils.execute(
-                cfg.CONF[CFG_GROUP].gdnsd_cmd_name,
+                cfg.CONF[CFG_GROUP_NAME].gdnsd_cmd_name,
                 '-D', '-x', 'checkconf', '-c', self._confdir_path,
                 run_as_root=False,
             )
@@ -169,7 +155,7 @@ class GdnsdBackend(base.AgentBackend):
     def _generate_zone_filename(self, zone_name):
         """Generate a filename for a zone file
         "/" is traslated into "@"
-        Non-valid characters are translated into \ NNN
+        Non-valid characters are translated into \\ NNN
         where NNN is a decimal integer in the range 0 - 255
         The filename is lowercase
 
@@ -185,7 +171,9 @@ class GdnsdBackend(base.AgentBackend):
         """Create or update a zone file atomically.
         The zone file is written to a unique temp file and then renamed
         """
-        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
+        zone_name = zone.origin.to_text(omit_final_dot=True)
+        if isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
         zone_base_fname = self._generate_zone_filename(zone_name)
         zone_fname = os.path.join(self._zonedir_path, zone_base_fname)
         try:
